@@ -1,24 +1,14 @@
 /*
- * This file is part of the KDE libraries
- * Copyright (c) 2006 Lubos Lunak <l.lunak@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006 Lubos Lunak <l.lunak@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include <config-kdeinit.h>
 
+#define _POSIX_C_SOURCE 200809L /* kill(2) */
+
 #include <errno.h>
 #include <fcntl.h>
 #include <signal.h>
